@@ -135,7 +135,6 @@ cosmos_pkn <- function(
 }
 
 
-
 #' Build prior knowledge network for COSMOS
 #'
 #' The prior knowledge network (PKN) used by COSMOS is a network of
@@ -199,15 +198,14 @@ cosmos_pkn <- function(
 #'     omics analysis. Molecular Systems Biology. 2021 Mar;17(3):e9923.
 #'
 #' @importFrom magrittr %>%
-#'
 #' @noRd
-#'
 .cosmos_pkn <- function(
     organism = 'human',
     protein_ids = c('uniprot', 'genesymbol'),
     metabolite_ids = c('hmdb', 'kegg'),
     chalmers_gem_metab_max_degree = 400L,
     stitch_score = 700L,
+    ksn_list = c("PhosphoSite", "DEPOD","SIGNOR"),
     ...
 ) {
 
@@ -222,13 +220,17 @@ cosmos_pkn <- function(
         organism
     )
 
-    stitch <- stitch_network(
+
+    stitch <- cosmos_stitch(
         organism = organism,
-        min_score = stitch_score,
-        protein_ids = protein_ids,
-        metabolite_ids = metabolite_ids,
-        cosmos = TRUE
+        stitch_score = stitch_score,
+        protein_ids = c('uniprot', 'genesymbol'),
+        metabolite_ids = c('hmdb', 'kegg')
     )
+    ksn <- cosmos_ksn(ksn_list)
+    signaling <- cosmos_signaling()
+    grn <- cosmos_grn()
+    ligrec <- cosmos_ligrec()
 
     chalmers <- chalmers_gem_network(
         organism_or_gem = organism,
@@ -249,6 +251,87 @@ cosmos_pkn <- function(
 }
 
 
+#' @noRd
+cosmos_stitch <- function(
+    organism,
+    stitch_score,
+    protein_ids,
+    metabolite_ids
+){
+
+    stitch = stitch_network(
+        organism = organism,
+        min_score = stitch_score,
+        protein_ids = protein_ids,
+        metabolite_ids = metabolite_ids,
+        cosmos = TRUE,
+        metabolite_protein_only = TRUE
+    )
+
+}
+
+
+#' @noRd
+cosmos_ksn <- function(ksn_list){
+
+    # NSE vs. R CMD check workaround
+    residue_type <- residue_offset <- substrate_genesymbol <-
+        modification <- mor <- target <- NULL
+
+    KSN <-
+        enzyme_substrate(resources = ksn_list) %>%
+        mutate(
+           target = sprintf(
+               '%s_%s%i',
+               substrate_genesymbol,
+               residue_type,
+               residue_offset
+           )
+        ) %>%
+        mutate(
+            mor = case_when(
+                modification == "phosphorylation" ~ 1L,
+                modification == "dephosphorylation" ~ -1L,
+                TRUE ~ NA_integer_
+            )
+        ) %>%
+        select(
+            source = enzyme_genesymbol,
+            target = target,
+            mor = mor
+        )
+
+    # kinasephos = kinasephos()
+}
+
+
+#' @noRd
+cosmos_signaling <- function(){
+  core_pkn = omnipath() %>%
+    filter(!is.na(references)) %>%
+    filter(consensus_stimulation == 1 | consensus_inhibition == 1) %>%
+    mutate(sign = consensus_stimulation - consensus_inhibition) %>%
+    select(source = source_genesymbol,target = target_genesymbol,sign) %>%
+    {bind_rows(
+      filter(.,sign != 0),
+      filter(.,sign == 0) %>% mutate(sign=1),
+      filter(.,sign == 0) %>% mutate(sign = -1)
+    )} %>% as.data.frame()
+}
+
+
+#' @noRd
+cosmos_grn <- function(){
+  tf_mRNA = collectri()
+}
+
+
+#' @noRd
+cosmos_ligrec <- function(){
+  ligrec_pkn = curated_ligand_receptor_interactions() %>% distinct()
+}
+
+
 #' OmniPath PPI for the COSMOS PKN
 #'
 #' @param organism Character or integer: name or NCBI Taxonomy ID of the
